@@ -12,7 +12,7 @@ use Compress::Zlib();
 use JSON();
 use overload '""' => 'string';
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 sub new {
     my ( $class, $params ) = @_;
@@ -32,23 +32,16 @@ sub _init {
 }
 
 sub gzip {
-    my ( $self, $string ) = @_;
+    my ($self) = @_;
     my $gzipped = Compress::Zlib::memGzip( $self->string() )
       or Carp::croak('Failed to gzip HAR archive');
     return $gzipped;
 }
 
-sub string {
-    my ( $self, $string ) = @_;
-    my $json = JSON->new();
-    $json = $json->utf8();
-    $json = $json->allow_blessed(1);
-    $json = $json->convert_blessed(1);
-    $json = $json->pretty();
-    my $old = $json->encode($self);
-    if ( ( @_ > 1 ) && ( defined $string ) ) {
+sub hashref {
+    my ( $self, $ref ) = @_;
+    if ( ( @_ > 1 ) && ( defined $ref ) ) {
         $self->_init();
-        my $ref = JSON->new()->utf8()->decode($string);
         $self->version( $ref->{log}->{version} );
         $self->creator( Archive::Har::Creator->new( $ref->{log}->{creator} ) );
         if ( defined $ref->{log}->{browser} ) {
@@ -61,6 +54,21 @@ sub string {
         $self->entries( $ref->{log}->{entries} );
         $self->comment( $ref->{log}->{comment} );
     }
+    return;
+}
+
+sub string {
+    my ( $self, $string ) = @_;
+    my $json = JSON->new();
+    $json = $json->utf8();
+    $json = $json->allow_blessed(1);
+    $json = $json->convert_blessed(1);
+    $json = $json->pretty();
+    my $old = $json->encode($self);
+    if ( ( @_ > 1 ) && ( defined $string ) ) {
+        my $ref = JSON->new()->utf8()->decode($string);
+        $self->hashref($ref);
+    }
     return $old;
 }
 
@@ -460,9 +468,9 @@ Archive::Har - Provides an interface to HTTP Archive (HAR) files
 
 =head1 VERSION
 
-Version 0.12
+Version 0.13
 
-=for stopwords xml gzip stringified HAR gzipped gzipping JSON
+=for stopwords xml gzip stringified HAR gzipped gzipping JSON hashref
 
 =head1 SYNOPSIS
 
@@ -497,6 +505,10 @@ Archive::Har->new() will return a new HAR object, ready to process HTTP archives
 
 $har->string() accepts a stringified version of an L<HTTP archive|http://www.softwareishard.com/blog/har-12-spec/> and parses it.  It returns the previous state of the archive in stringified form
 
+=head2 hashref
+
+$har->hashref() accepts a hashref of the L<HTTP archive|http://www.softwareishard.com/blog/har-12-spec/> and parses it.  There is no return value.
+
 =head2 gzip
 
 $har->gzip() returns a gzipped copy of the current state of the archive in stringified form
@@ -551,8 +563,10 @@ Archive::Har requires the following non-core Perl modules
 
 =item *
 L<JSON|JSON>
+
 =item *
 L<Compress::Zlib|Compress::Zlib>
+
 =item *
 L<XML::LibXML|XML::LibXML>
 
@@ -585,7 +599,3 @@ under the terms of either: the GNU General Public License as published
 by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
-
-
-=cut
-
