@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp();
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 sub new {
     my ( $class, $params ) = @_;
@@ -29,13 +29,18 @@ sub name {
     my ( $self, $new ) = @_;
     my $old = $self->{name};
     if ( @_ > 1 ) {
-        $self->{name} = $new;
+        if ( defined $new ) {
+            $self->{name} = $new;
+        }
+        else {
+            $self->{name} = 'Unknown';
+        }
     }
-    if ( defined $old ) {
-        return $old;
+    if ( ( defined $old ) && ( $old eq 'Unknown' ) ) {
+        return;
     }
     else {
-        return 'Unknown';
+        return $old;
     }
 }
 
@@ -43,13 +48,18 @@ sub version {
     my ( $self, $new ) = @_;
     my $old = $self->{version};
     if ( @_ > 1 ) {
-        $self->{version} = $new;
+        if ( defined $new ) {
+            $self->{version} = $new;
+        }
+        else {
+            $self->{version} = 'Unknown';
+        }
     }
-    if ( defined $old ) {
-        return $old;
+    if ( ( defined $old ) && ( $old eq 'Unknown' ) ) {
+        return;
     }
     else {
-        return 'Unknown';
+        return $old;
     }
 }
 
@@ -85,10 +95,19 @@ sub AUTOLOAD {
 
 sub TO_JSON {
     my ($self) = @_;
-    my $json = {
-        name    => $self->name(),
-        version => $self->version(),
-    };
+    my $json = {};
+    if ( defined $self->name() ) {
+        $json->{name} = $self->name();
+    }
+    else {
+        $json->{name} = 'Unknown';
+    }
+    if ( defined $self->version() ) {
+        $json->{version} = $self->version();
+    }
+    else {
+        $json->{version} = 'Unknown';
+    }
     if ( defined $self->comment() ) {
         $json->{comment} = $self->comment();
     }
@@ -109,7 +128,7 @@ Archive::Har::Creator - Represents the creator (software) of the HTTP Archive
 
 =head1 VERSION
 
-Version 0.12
+Version 0.13
 
 =for stopwords HAR
 
@@ -189,7 +208,3 @@ under the terms of either: the GNU General Public License as published
 by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
-
-
-=cut
-
