@@ -5,7 +5,7 @@ use strict;
 use Carp();
 use Archive::Har::Entry::Cache::Request();
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 sub new {
     my ( $class, $params ) = @_;
@@ -127,7 +127,9 @@ Archive::Har::Entry::Cache - Represents the cache for a single request/response
 
 =head1 VERSION
 
-Version 0.12
+Version 0.13
+
+=for stopwords HAR
 
 =head1 SYNOPSIS
 
@@ -140,9 +142,15 @@ Version 0.12
         my $cache = $entry->cache();
 	my $before = $cache->before_request();
 	my $after = $cache->after_request();
+        $after->comment("Something interesting here");
 	print "Comment: " . $cache->comment() . "\n";
     }
 
+=head1 DESCRIPTION
+ 
+This Module is intended to provide an interface to create/read/update
+Cache objects in HTTP Archive (HAR) files.
+
 =head1 SUBROUTINES/METHODS
 
 =head2 new
@@ -159,5 +167,46 @@ returns the L<state|Archive::Har::Entry::Cache::Request> of the cache after the
 
 =head2 comment
 
-returns the comment about the Entry
+returns the comment about the Cache
 
+=head1 DIAGNOSTICS
+
+=over
+
+=item C<< %s is not specified in the HAR 1.2 spec and does not start with an underscore >>
+
+The HAR 1.2 specification allows undocumented fields, but they must start with an underscore
+
+=back
+
+=head1 CONFIGURATION AND ENVIRONMENT
+
+Archive::Har::Entry::Cache requires no configuration files or environment variables.  
+
+=head1 DEPENDENCIES
+
+Archive::Har::Entry::Cache requires no additional non-core Perl modules
+
+=head1 INCOMPATIBILITIES
+
+None reported
+
+=head1 AUTHOR
+
+David Dick, C<< <ddick at cpan.org> >>
+
+=head1 BUGS AND LIMITATIONS
+
+Please report any bugs or feature requests to C<bug-archive-har at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Archive-Har>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2015 David Dick.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
