@@ -7,7 +7,7 @@ use Archive::Har::Entry::Header();
 use Archive::Har::Entry::Cookie();
 use Archive::Har::Entry::Response::Content();
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 sub _DOES_NOT_APPLY { return -1 }
 
@@ -246,7 +246,9 @@ Archive::Har::Entry::Response - Represents a single http response inside the HTT
 
 =head1 VERSION
 
-Version 0.12
+Version 0.13
+
+=for stopwords HAR http CRLF
 
 =head1 SYNOPSIS
 
@@ -271,6 +273,11 @@ Version 0.12
 	print "Comment: " . $response->comment() . "\n";
     }
 
+=head1 DESCRIPTION
+ 
+This Module is intended to provide an interface to create/read/update
+Response objects in HTTP Archive (HAR) files.
+
 =head1 SUBROUTINES/METHODS
 
 =head2 new
@@ -317,5 +324,44 @@ returns the total number of bytes in the http response body
 
 returns the comment about the Entry
 
-=cut
+=head1 DIAGNOSTICS
 
+=over
+
+=item C<< %s is not specified in the HAR 1.2 spec and does not start with an underscore >>
+
+The HAR 1.2 specification allows undocumented fields, but they must start with an underscore
+
+=back
+
+=head1 CONFIGURATION AND ENVIRONMENT
+
+Archive::Har::Entry::Response requires no configuration files or environment variables.  
+
+=head1 DEPENDENCIES
+
+Archive::Har::Entry::Response requires no additional non-core Perl modules
+
+=head1 INCOMPATIBILITIES
+
+None reported
+
+=head1 AUTHOR
+
+David Dick, C<< <ddick at cpan.org> >>
+
+=head1 BUGS AND LIMITATIONS
+
+Please report any bugs or feature requests to C<bug-archive-har at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Archive-Har>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2015 David Dick.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
