@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp();
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 sub _DOES_NOT_APPLY { return -1 }
 
@@ -140,7 +140,7 @@ Archive::Har::Page::PageTimings - Represents detailed timing of page within the
 
 =head1 VERSION
 
-Version 0.12
+Version 0.13
 
 =for stopwords HAR PageTimings undef
 
@@ -153,6 +153,7 @@ Version 0.12
     $har->string($http_archive_string);
     foreach my $page ($har->pages()) {
         my $timings = $page->pageTimings();
+        $timings->comment("Something interesting here");
 	print "onContentLoad for " . $page->title() . ": " . $timings->on_content_load() . "\n";
 	print "onLoad for " . $page->title() . ": " . $timings->on_load() . "\n";
         print "Comment for " . $page->title() . ": " . $timings->comment() . "\n";
@@ -230,7 +231,3 @@ under the terms of either: the GNU General Public License as published
 by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
-
-
-=cut
-
